# BingAI (ChatGPT)

## Bing AI API for ChatGPT

### Installation

```
pip install bingai --upgrade
```

## Important Feature - No Manual Intervention Required
```
100% Programmatic Run
Edge browser opens up and automatically fetches tokens, no manual intervention whatsoever
```

### Usage
```
from bingai import BingSession
session = BingSession(email, password)
session.run()
```

Microsoft credentials for the account which has access to the Bing Chat feature
